@@ -15,4 +15,4 @@ class ParameterRequiredError(Error):
         self.params = params
 
     def __str__(self):
-        return "%s is mandatory, but received empty." % (", ".join(self.params))
+        return "{} is mandatory, but received empty.".format(", ".join(self.params))
